==> species-discovery-3.3.0-20130703.142037-1-sources.jar: org/gcube/portlets/user/speciesdiscovery/server/util/StorageUtil.java <==
package org.gcube.portlets.user.speciesdiscovery.server.util;

//import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLStreamHandler;

import org.gcube.common.core.utils.logging.GCUBELog;
import org.gcube.contentmanager.storageclient.model.protocol.smp.Handler;
import org.gcube.contentmanager.storageclient.model.protocol.smp.SMPURLConnection;

public class StorageUtil {
	protected static GCUBELog logger = new GCUBELog(StorageUtil.class);
	
	//Storage version 1.0
//	public static InputStream getInputStreamByStorageClient(String url) throws Exception {
	
//		logger.trace("url :" + url);
//		
//		String [] urlParam=url.split("\\?");
////		String param=urlParam[1];
//		logger.info("String encrypted "+urlParam[1]);
//		String param=new StringEncrypter("DES").decrypt(urlParam[1]);
//		logger.info("String decrypted: "+param);
//		String [] getParam=param.split("\\&");
//		String serviceClass=null;
//		String serviceName=null;
//		String owner=null;
//		String accessType=null;
//		String scopeType=null;
//		AccessType type = null;
//		String server= null;
//		String [] par1;
//		for(String par : getParam){
//			if(par.contains("ServiceClass")){
//				par1=par.split("=");
//				serviceClass=par1[1];
//			}else if(par.contains("ServiceName")){
//				par1=par.split("=");
//				serviceName=par1[1];
//			}else if(par.contains("owner")){
//				par1=par.split("=");
//				owner=par1[1];
//			}else if(par.contains("scope")){
//				par1=par.split("=");
//				scopeType=par1[1];
//			}else if(par.contains("server")){
//				par1=par.split("=");
//				server=par1[1];
//			}else if(par.contains("AccessType")){
//				par1=par.split("=");
//				accessType=par1[1];			
//				if(accessType.equalsIgnoreCase("public")){
//					type=AccessType.PUBLIC;
//				}else if(accessType.equalsIgnoreCase("shared")){
//					type=AccessType.SHARED;
//				}
//			}else{
//				;
//			}
//		}
//		if((serviceName==null) || (serviceClass==null) || (owner == null) || (scopeType==null) || (type == null))
//			throw new MalformedURLException();
//		GCUBEScope scope=GCUBEScope.getScope(scopeType);
//		String location=extractLocation(urlParam[0]);
//
//		logger.trace("Storage instance with parameters "+serviceClass+" "+serviceName+" "+owner+" "+type+" "+scope+ " location: "+urlParam[0]);
//		IClient client=new StorageClient(serviceClass, serviceName, owner, type, scope, server).getClient();
//		InputStream is=null;
//		is=client.get().RFileAStream(location);
//		createFileTest(is);
		
//	}
	
	public static InputStream getInputStreamByStorageClient(String url) throws Exception {

		Handler.activateProtocol();

		URL smsHome = null;
		try {
			
			 smsHome = new URL(null, url, new URLStreamHandler() {
	               
                @Override
                protected URLConnection openConnection(URL u) throws IOException {
                    return new SMPURLConnection(u);
                }
            });
			 
//			smsHome = new URL(url);
		} catch (MalformedURLException e1) {
			e1.printStackTrace();
		}
		URLConnection uc = null;
		uc = ( URLConnection ) smsHome.openConnection();
		InputStream is=uc.getInputStream();
		return is;
	}
	
	
//	public static InputStream getInputStreamByStorageClient(String url) throws Exception {
//
//		Handler.activateProtocol();
//		URL smsHome = null;
//		try {
//			smsHome = new URL(url);
//		} catch (MalformedURLException e1) {
//			e1.printStackTrace();
//		}
//		URLConnection uc = null;
//		uc = ( URLConnection ) smsHome.openConnection();
//		InputStream is=uc.getInputStream();
//		return is;
//	}

//	public static String extractLocation(String url) {
//		String [] loc=url.split("//");
//		logger.trace("url extracted: "+loc[1]);
//		return loc[1];
//	}

}

==> species-discovery-3.11.0-20211102.103836-6-sources.jar: org/gcube/portlets/user/speciesdiscovery/server/util/StorageUtil.java <==
package org.gcube.portlets.user.speciesdiscovery.server.util;

//import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLStreamHandler;

import org.apache.log4j.Logger;
import org.gcube.contentmanager.storageclient.model.protocol.smp.Handler;
import org.gcube.contentmanager.storageclient.model.protocol.smp.SMPURLConnection;

public class StorageUtil {
	
	protected static Logger logger = Logger.getLogger(StorageUtil.class);
	
	public static InputStream getInputStreamByStorageClient(String url) throws Exception {

		Handler.activateProtocol();

		URL smsHome = null;
		try {
			
			 smsHome = new URL(null, url, new URLStreamHandler() {
	               
                @Override
                protected URLConnection openConnection(URL u) throws IOException {
                    return new SMPURLConnection(u);
                }
            });
			 
//			smsHome = new URL(url);
		} catch (MalformedURLException e1) {
			e1.printStackTrace();
		}
		URLConnection uc = null;
		uc = ( URLConnection ) smsHome.openConnection();
		InputStream is=uc.getInputStream();
		return is;
	}

	public static void main(String[] args) throws Exception {
		
		InputStream is = getInputStreamByStorageClient("smp:/51e1065ee4b0a159b8c25cc8?5ezvFfBOLqb2cBxvyAbVnOhbxBCSqhv+Z4BC5NS/+OwS5RYBeaUL5FS9eDyNubiTI4vSpggUgPA+jm9rQxwbisfhkOW/m6l2IYG9BKb8AEJFLgVvG3FJTk0+4xV9iM/hNQvChZjoJZna0aPXkHN4Eg==");
		
		
		
	}

}
